@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Restrict Senders Plugin
-  * Copyright (c) 2003-2011 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -383,12 +383,7 @@ function check_restrict_senders_do(&$argv)
           $vlogin_restrictSubsequentMassEmailsWhitelist, $rs_debug,
           $whitelisted_addresses, $rs_delimiter, $log_too_many_recipients,
           $log_too_many_today, $log_too_many_subsequent_mass_emails,
-          $log_no_recipients, $rs_clear_prefs_cache_on_send, $draft;
-
-
-   // don't restrict saving of drafts
-   //
-   if (!empty($draft)) return;
+          $log_no_recipients, $rs_clear_prefs_cache_on_send;
 
 
    if (check_sm_version(1, 5, 2))
